@@ -34,8 +34,6 @@ main = do
     where
       isDataCon (L _ (AbsBinds { abs_binds = bs }))
         = not (isEmptyBag (filterBag isDataCon bs))
-      isDataCon (L _ (AbsBindsSig { abs_sig_bind = b }))
-        = isDataCon b
       isDataCon (L l (f@FunBind {}))
         | (MG (L _ (m:_)) _ _ _) <- fun_matches f,
           (L _ (c@ConPatOut{}):_)<-hsLMatchPats m,
