@@ -4,4 +4,7 @@ module T11399 where
 import Data.Kind
 
 newtype UhOh (k :: * -> *) (a :: k *) = UhOh (k *)
-instance Functor k => Functor (UhOh k) where
+
+-- UhOh :: forall (k : * -> *). k * -> *
+
+instance Functor a => Functor (UhOh a) where
