@@ -1,5 +1,9 @@
 {-# LANGUAGE DataKinds #-}
+{-# LANGUAGE KindSignatures #-}
+{-# LANGUAGE ConstraintKinds #-}
 {-# LANGUAGE TypeInType #-}
+{-# LANGUAGE UnboxedTuples #-}
+{-# LANGUAGE MagicHash #-}
 {-# LANGUAGE TypeApplications #-}
 {-# LANGUAGE ScopedTypeVariables #-}
 {-# LANGUAGE AllowAmbiguousTypes #-}
@@ -30,6 +34,12 @@ main = do
   print $ rep @Bool
   print $ rep @Ordering
   print $ rep @(Int -> Int)
+  print $ rep @((Eq Int, Eq String) :: Constraint)
+
+  -- Unboxed things (#12049)
+  print $ rep @Int#
+  print $ rep @(##)
+  print $ rep @(# Int#, Int #)
 
   -- Various instantiations of a kind-polymorphic type
   print $ rep @(Proxy (Eq Int))
@@ -39,10 +49,10 @@ main = do
   print $ rep @(Proxy [1,2,3])
   print $ rep @(Proxy 'EQ)
   print $ rep @(Proxy TYPE)
-  print $ rep @(Proxy (TYPE 'PtrRepLifted))
+  print $ rep @(Proxy (TYPE 'LiftedRep))
   print $ rep @(Proxy *)
   print $ rep @(Proxy ★)
-  print $ rep @(Proxy 'PtrRepLifted)
+  print $ rep @(Proxy 'LiftedRep)
 
   -- Something lifted and primitive
-  print $ rep @RealWorld
+  print $ rep @RealWorld  -- #12132
